@@ -56,6 +56,13 @@
 
 #define ID_STRING_2002  "クリア!!"
 #define ID_STRING_2003  "全ての牌を取りました!\nクリア時間:%1"
+#define ID_STRING_2004  "全ての牌を取りました!\nハイスコアに登録されました。\nクリア時間:%1"
+
+//ScoreListDaialog
+#define ID_STRING_2010 "ハイスコア"
+#define ID_STRING_2011 "順位"
+#define ID_STRING_2012 "クリアタイム"
+#define ID_STRING_2013 "日付"
 
 
 
